@@ -360,6 +360,7 @@ pub async fn spawn_transport_listener_quic(
 
 // TODO - modernize all this taking hints from TLS code in proxy crate.
 mod danger {
+    use crate::legacy_lair_api;
     use kitsune_p2p_types::transport::TransportError;
     use kitsune_p2p_types::transport::TransportResult;
     use once_cell::sync::Lazy;
@@ -403,20 +404,19 @@ mod danger {
     #[allow(dead_code)]
     pub(crate) async fn configure_server(
         cert: Option<(
-            lair_keystore_api::actor::Cert,
-            lair_keystore_api::actor::CertPrivKey,
+            legacy_lair_api::actor::Cert,
+            legacy_lair_api::actor::CertPrivKey,
         )>,
     ) -> TransportResult<ServerConfig> {
         let (cert, cert_priv) = match cert {
             Some(r) => r,
             None => {
-                let mut options = lair_keystore_api::actor::TlsCertOptions::default();
-                options.alg = lair_keystore_api::actor::TlsCertAlg::PkcsEcdsaP256Sha256;
-                let cert = lair_keystore_api::internal::tls::tls_cert_self_signed_new_from_entropy(
-                    options,
-                )
-                .await
-                .map_err(TransportError::other)?;
+                let mut options = legacy_lair_api::actor::TlsCertOptions::default();
+                options.alg = legacy_lair_api::actor::TlsCertAlg::PkcsEcdsaP256Sha256;
+                let cert =
+                    legacy_lair_api::internal::tls::tls_cert_self_signed_new_from_entropy(options)
+                        .await
+                        .map_err(TransportError::other)?;
                 (cert.cert_der, cert.priv_key_der)
             }
         };
